@@ -49,12 +49,12 @@ class L0ToHfrTimeLog(Task):
         # Get start_time input value
         self.start_time = valid_time(self.pipeline.get(
             'start_time', default=[None])[0],
-            format=TIME_DAILY_STRFORMAT)
+                                     format=TIME_DAILY_STRFORMAT)
 
         # Get end_time input value
         self.end_time = valid_time(self.pipeline.get(
             'end_time', default=[None])[0],
-            format=TIME_DAILY_STRFORMAT)
+                                   format=TIME_DAILY_STRFORMAT)
 
         # get a database session, table model and table columns (except primary key)
         self.session = Connector.manager[PIPELINE_DATABASE].session
@@ -141,17 +141,20 @@ class L0ToHfrTimeLog(Task):
                     self.l0_end_time = datetime.strptime(
                         l0.attrs['TIME_MAX'], TIME_ISO_STRFORMAT)
 
-                    # Retrieve existing data from pipeline.hfr_time_log table between each L0 file processing
-                    # (Content may change between two L0 files)
+                    # Retrieve existing data from pipeline.hfr_time_log table before each L0 file processing
+                    # (Database content may change between two L0 file processes)
                     logger.debug(f'Getting existing hfr_time_log data between {self.start_time} and {self.end_time}')
                     # Return existing data as a pandas.DataFrame object
                     table_data = query_db(self.session, self.model,
-                                        filters=and_(*self.filters),
-                                        tryouts=self.tryouts,
-                                        wait=self.wait,
-                                        limit=self.limit,
-                                        )
+                                          filters=(and_(*self.filters) if self.filters else None),
+                                          tryouts=self.tryouts,
+                                          wait=self.wait,
+                                          limit=self.limit,
+                                          )
                     n_existing = table_data.shape[0]
+                    # If data have been found in the database, then building and adding a new "coarse_fine" variable.
+                    # This variable will be used to handle and compare times in the data
+                    # (more simple than with [coarse, fine] vectors)
                     if n_existing > 0:
                         table_data['coarse_fine'] = table_data.apply(
                             lambda x: self.merge_coarse_fine(x['coarse_time'], x['fine_time'])
@@ -200,13 +203,14 @@ class L0ToHfrTimeLog(Task):
                             raise ValueError(f'Unknown HFR mode for {packet_name} in {current_l0_file}')
 
                         # Convert PA_THR_ACQUISITION_TIME values into unique integers
+                        # (To be comparable with "coarse_fine" variable in database table_data)
                         packet_df['coarse_fine'] = packet_df['PA_THR_ACQUISITION_TIME'].apply(
-                            lambda x :self.merge_coarse_fine(x[0],x[1])
+                            lambda x: self.merge_coarse_fine(x[0], x[1])
                         )
 
                         # Do the same for packet creation time
                         packet_df['packet_time'] = packet_df['time'].apply(
-                            lambda x :self.merge_coarse_fine(x[0],x[1])
+                            lambda x: self.merge_coarse_fine(x[0], x[1])
                         )
 
                         # Extract values of delta times for HF1 and HF2 for each packet
@@ -218,20 +222,22 @@ class L0ToHfrTimeLog(Task):
                                     axis=1
                                 ))
                             except:
-                                logger.exception(f'Extraction delta_time values from {packet_name} in {current_l0_file} has failed!')
+                                logger.exception(
+                                    f'Extraction delta_time values from {packet_name} in {current_l0_file} has failed!')
                                 self.failed_files.append(current_l0_file)
                                 break
 
                         # Get list of unique PA_THR_ACQUISITION_TIME values
                         unique_coarse_fine = packet_df['coarse_fine'].unique()
                         n_entry = unique_coarse_fine.shape[0]
-                        logger.info(f'{n_entry} {packet_name} entries to insert into hfr_time_log table for {current_l0_file}')
+                        logger.info(
+                            f'{n_entry} {packet_name} entries to insert into hfr_time_log table for {current_l0_file}')
                         for i in range(n_entry):
                             # Get subset of packet data for current acquisition time
                             current_indices = packet_df.index[unique_coarse_fine[i] == packet_df['coarse_fine']]
                             current_df = packet_df.iloc[current_indices].reset_index(drop=True)
 
-                            # Set entry dictionary
+                            # Fill new database entry dictionary
                             current_entry = {}
                             current_entry['coarse_time'] = int(current_df['PA_THR_ACQUISITION_TIME'][0][0])
                             current_entry['fine_time'] = int(current_df['PA_THR_ACQUISITION_TIME'][0][1])
@@ -241,27 +247,32 @@ class L0ToHfrTimeLog(Task):
 
                             if self.mode != 2:
                                 # For delta_time1 and delta_time2 columns, make sure to concatenate all values
-                                # Save delta_time1 and delta_time2 as dictionaries with packet creation times as keywords
+                                # Save delta_time1 and delta_time2 as (JSONB format) dictionaries
+                                # with packet creation times as keywords
                                 # and delta_time1 and delta_time2 block values as values
                                 current_entry['delta_time1'] = {}
                                 current_entry['delta_time2'] = {}
                                 for j in range(current_df.shape[0]):
-                                    current_entry['delta_time1'][str(int(current_df['packet_time'][j]))] = current_df['delta_time1'][j].astype(int).tolist()
-                                    current_entry['delta_time2'][str(int(current_df['packet_time'][j]))] = current_df['delta_time2'][j].astype(int).tolist()
+                                    current_entry['delta_time1'][str(int(current_df['packet_time'][j]))] = \
+                                    current_df['delta_time1'][j].astype(int).tolist()
+                                    current_entry['delta_time2'][str(int(current_df['packet_time'][j]))] = \
+                                    current_df['delta_time2'][j].astype(int).tolist()
 
                             # Check if data for current acquisition time already in the database
                             try:
                                 current_table_df = table_data[unique_coarse_fine[i] == table_data['coarse_fine']]
                                 current_table_df.reset_index(inplace=True)
                             except:
-                                logger.debug(f'No {packet_name} entry found in the hfr_time_log table for {current_entry["acq_time"]}')
+                                logger.debug(
+                                    f'No {packet_name} entry found in the hfr_time_log table for {current_entry["acq_time"]}')
                                 data_to_insert = current_entry
                             else:
                                 # if data found, then merge data before inserting
                                 data_to_insert = self.merge_data(current_entry, current_table_df)
 
                                 if data_to_insert is None:
-                                    logger.info(f'No new {packet_name} data to insert in hfr_time_log table for {current_entry["acq_time"]}')
+                                    logger.info(
+                                        f'No new {packet_name} data to insert in hfr_time_log table for {current_entry["acq_time"]}')
                                     continue
                                 elif self.mode != 2:
                                     # Sort delta_time dictionaries by ascending packet creation times
@@ -269,16 +280,16 @@ class L0ToHfrTimeLog(Task):
                                     data_to_insert['delta_time2'] = dict(sorted(data_to_insert['delta_time2'].items()))
 
                             # define columns to check for update
-                            update_fields_kwargs = {key:val
+                            update_fields_kwargs = {key: val
                                                     for key, val in data_to_insert.items()
                                                     if key not in ['delta_time1', 'delta_time2']}
 
                             # Insert entry in the hfr_time_log table
                             insert_status = insert_in_db(self.session, self.model, data_to_insert,
-                                            update_fields=data_to_insert,
-                                            update_fields_kwargs=update_fields_kwargs,
-                                            tryouts = self.tryouts,
-                                            wait=self.wait,
+                                                         update_fields=data_to_insert,
+                                                         update_fields_kwargs=update_fields_kwargs,
+                                                         tryouts=self.tryouts,
+                                                         wait=self.wait,
                                                          )
                             if insert_status < 0:
                                 logger.error(f'Inserting {update_fields_kwargs} in pipeline.hfr_time_log table '
@@ -379,8 +390,8 @@ class L0ToHfrTimeLog(Task):
         # store because of the garbage collector removing reference while
         # processing in cython
         byte = np.array(packet_data[
-                   "PA_THR_HFR_DATA"
-               ][:size], dtype=np.uint16).byteswap().newbyteorder().tobytes()
+                            "PA_THR_HFR_DATA"
+                        ][:size], dtype=np.uint16).byteswap().newbyteorder().tobytes()
         data = Data(byte, len(byte))
 
         # init offset
@@ -400,7 +411,6 @@ class L0ToHfrTimeLog(Task):
             hfr_setup_cmd = self._hfr_setup(data, offset)
             offset += 2
 
-
             # Skip input setup bits
             offset += 2
 
@@ -493,7 +503,7 @@ class L0ToHfrTimeLog(Task):
 
         return sw, initial_frequency, hf2, hf1, av
 
-    def _hfr_sweep_setup (self, data, start):
+    def _hfr_sweep_setup(self, data, start):
         """
         Return tuple of values from the HFR sweep setup command.
         """
